# -*- coding: utf-8 -*-

# Define self package variable
__version__ = "0.2.3"
__all__ = ["NanoCount", "Read"]
__description__ = "EM based transcripts abundance estimation from nanopore reads mapped to a transcriptome with minimap2"
